#
# spec file for package python-autodocsumm
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-autodocsumm
Version:        0.2.14
Release:        1.3
Summary:        Extended sphinx autodoc including automatic autosummaries
License:        Apache-2.0
URL:            https://github.com/Chilipp/autodocsumm
Source:         https://github.com/Chilipp/autodocsumm/archive/v%{version}.tar.gz#/autodocsumm-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module versioneer}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Sphinx >= 2.2
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Sphinx >= 2.2}
BuildRequires:  %{python_module beautifulsoup4}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
Extended sphinx autodoc including automatic autosummaries

%prep
%autosetup -p1 -n autodocsumm-%{version}
# Remove guard from Sphinx version
sed -i 's/,<5.0//' setup.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/autodocsumm
%{python_sitelib}/autodocsumm-%{version}.dist-info

%changelog
* Thu Oct 24 2024 Nico Krapp <nico.krapp@suse.com>
- Update to 0.2.14
  * Fix ObjectMember related deprecation/removal by @theOehrly
  * Type hint mixin base class, fix some more minor style and typing issues by @theOehrly
  * Don't document class attributes that are an alias to another object by @theOehrly
  * Autoexception support by @Chilipp
* Mon Aug 26 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.2.13
  * Allow Sphinx >=8.0 and fix deprecations; allow Python
    3.12; rework test workflow by @theOehrly in (#98)
* Mon Jan  8 2024 Dirk Müller <dmueller@suse.com>
- update to 0.2.12:
  * small fix for tests
  * fix docs
  * An option to sort sections
- drop sphinx72.patch (upstream)
* Mon Aug 28 2023 Markéta Machová <mmachova@suse.com>
- Add patch sphinx72.patch
* Fri May 19 2023 Jiri Srain <jsrain@suse.com>
- fixed the license tag to Apache-2.0
* Wed May 10 2023 Dirk Müller <dmueller@suse.com>
- update to 0.2.11:
  * Support Sphinx 7 and Python 3.11
  * pin build of docs to sphinx<=7.0
* Thu May  4 2023 Dirk Müller <dmueller@suse.com>
- update to 0.2.11:
  * Support Sphinx 7 and Python 3.11
  * Allow Sphinx v6
  * install versioneer
  * remove OrderedDict
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Wed Sep 28 2022 Daniel Garcia <daniel.garcia@suse.com>
- Remove sphinx-testing build dependency, it's not needed anymore
* Thu Aug  4 2022 Otto Hollmann <otto.hollmann@suse.com>
- Update to 0.2.9:
  * specify parser for BeautifulSoup
  * Allow Sphinx v5
  * Drop Python 3.6 support
  * Declare project and pytest configuration in pyproject.toml
* Fri Jun 24 2022 Steve Kowalik <steven.kowalik@suse.com>
- Remove guard on upper Sphinx version.
* Mon May  2 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 0.2.8
  * Fix: no links generated in summary table
  * Fix: Sphinx dependencies
* Sat Jul 10 2021 Matej Cepl <mcepl@suse.com>
- Update to 0.2.6:
  - license changed to Apache-2.0
  - This patch makes autodocsumm compatible with sphinx 4.0 and
    from now on requires python>=3.6.
  - implemented support for the :nosignatures:
* Sun Apr 18 2021 Ben Greiner <code@bnavigator.de>
- Update to 0.2.3
  * This Release makes autodocsumm compatible with sphinx 3.4 and
    3.5. See #42
- Release 0.2.2
  * This release fixes a bug that included imported members in the
    autosummary table (see #32, #33) and includes the sorting
    bysource (#34). We also dropped the dependency on six (#35).
- Release 0.2.1
  * Patch for compatibility with python 3.5
* Thu Sep  3 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.2.0:
  * No upstream changelog
* Fri Apr  3 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Initial build
  + Version 0.1.13
